@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Apply melodic inversion to a series of notes
 
-our $VERSION = '0.0104';
+our $VERSION = '0.0105';
 
 use Data::Dumper::Compact qw(ddc);
 use List::SomeUtils qw(first_index);
@@ -117,7 +117,7 @@ Music::MelodicDevice::Inversion - Apply melodic inversion to a series of notes
 
 =head1 VERSION
 
-version 0.0104
+version 0.0105
 
 =head1 SYNOPSIS
 
@@ -156,6 +156,12 @@ Default: C<C>
 
 Default: C<chromatic>
 
+For the chromatic scale, enharmonic notes are listed as sharps.  For a
+scale with flats, a diatonic B<scale_name> must be used with a flat
+B<scale_note>.
+
+Please see L<Music::Scales/SCALES> for a list of valid scale names.
+
 =head2 verbose
 
 Default: C<0>
